@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Hayo Baan's Dist::Zilla configuration
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 #pod =for test_synopsis
 #pod my @HAYOBAAN;
@@ -87,7 +87,7 @@ our $VERSION = '0.003'; # VERSION
 #pod
 #pod The following additional command-line option is available for the C<dzil> command.
 #pod
-#pod =head2 C<--local>, C<local_only>, C<local_release>, or C<--local_release_only>
+#pod =head2 C<--local_release_only>
 #pod
 #pod Adding this option to the C<dzil release> command will:
 #pod
@@ -99,7 +99,10 @@ our $VERSION = '0.003'; # VERSION
 #pod
 #pod The C<run_after_release> code is still run so you can use this flag to
 #pod "release" a development version locally for further use or testing,
-#pod without e.g., increasing the version number.
+#pod without e.g., fixing the new version number.
+#pod
+#pod C<--local>, C<--local_only>, and C<--local_release> are synonyms for
+#pod this option.
 #pod
 #pod =head1 STABILITY
 #pod
@@ -131,7 +134,8 @@ use Dist::Zilla::Plugin::ReadmeAnyFromPod ();
 use Dist::Zilla::Plugin::InstallGuide ();
 use Dist::Zilla::Plugin::MinimumPerl ();
 use Dist::Zilla::Plugin::GitHub::Meta ();
-use Dist::Zilla::Plugin::MetaProvides ();
+use Dist::Zilla::Plugin::MetaProvides::Package ();
+use Dist::Zilla::Plugin::MetaProvides::Class ();
 use Dist::Zilla::Plugin::CopyFilesFromBuild ();
 use Dist::Zilla::Plugin::Run ();
 use Dist::Zilla::Plugin::CheckChangesHasContent ();
@@ -141,6 +145,7 @@ use Dist::Zilla::Plugin::CheckMetaResources ();
 use Dist::Zilla::Plugin::CheckPrereqsIndexed ();
 use Dist::Zilla::Plugin::Test::Compile ();
 use Dist::Zilla::Plugin::Test::Perl::Critic ();
+use Test::Perl::Critic ();
 use Dist::Zilla::Plugin::Test::EOL ();
 use Dist::Zilla::Plugin::Test::NoTabs ();
 use Dist::Zilla::Plugin::Test::Version ();
@@ -152,6 +157,9 @@ use Dist::Zilla::Plugin::Test::UnusedVars ();
 use Dist::Zilla::Plugin::Test::CPAN::Changes ();
 use Dist::Zilla::Plugin::Test::DistManifest ();
 use Dist::Zilla::Plugin::Test::CPAN::Meta::JSON ();
+use Test::CPAN::Meta::JSON ();
+use Test::CPAN::Meta ();
+use Test::Pod::Coverage ();
 use Dist::Zilla::Plugin::Test::Pod::LinkCheck ();
 use Dist::Zilla::Plugin::Test::Synopsis ();
 use Dist::Zilla::Plugin::RunExtraTests ();
@@ -251,6 +259,9 @@ has no_git => (
 #pod
 #pod when I<releasing> the distribution.
 #pod
+#pod C<local>, C<local_only>, and C<local_release> are synonyms for
+#pod this setting.
+#pod
 #pod =cut
 
 has local_release_only => (
@@ -763,7 +774,7 @@ Dist::Zilla::PluginBundle::Author::HAYOBAAN - Hayo Baan's Dist::Zilla configurat
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 DESCRIPTION
 
@@ -844,7 +855,7 @@ following plugins are (conditionally) installed and configured:
 
 The following additional command-line option is available for the C<dzil> command.
 
-=head2 C<--local>, C<local_only>, C<local_release>, or C<--local_release_only>
+=head2 C<--local_release_only>
 
 Adding this option to the C<dzil release> command will:
 
@@ -870,7 +881,10 @@ keep the version number the same.
 
 The C<run_after_release> code is still run so you can use this flag to
 "release" a development version locally for further use or testing,
-without e.g., increasing the version number.
+without e.g., fixing the new version number.
+
+C<--local>, C<--local_only>, and C<--local_release> are synonyms for
+this option.
 
 =head1 ATTRIBUTES
 
@@ -926,6 +940,9 @@ keep the version number the same,
 
 when I<releasing> the distribution.
 
+C<local>, C<local_only>, and C<local_release> are synonyms for
+this setting.
+
 =head2 run_after_build
 
 Specifies commands to run after the release has been built (but not yet released). Multiple
